/**
  *  \file thread.cpp
  *  \brief Thread class definition for Unix
  */

#include "thread.h"

/** Constructor. */
Thread::Thread()
    : m_Thread(), m_Attr()
{
    pthread_attr_init(&m_Attr);
}

/** Destructor. Note that when the thread object dies before the
    thread is joined, its identifier is lost. */
Thread::~Thread()
{
    pthread_attr_destroy(&m_Attr);
}

void*
Thread::threadFunc(void* p)
{
    static_cast<Thread*>(p)->run();
    return 0;
}

/** Exit thread. To be called from run(). */
void
Thread::exit()
{
    pthread_exit(0);
}

/** Set stack size. Call this before start().
    \param n Desired stack size in bytes */
void
Thread::setStackSize(int n)
{
    pthread_attr_setstacksize(&m_Attr, n);
}

/** Start the thread. This creates the actual thread and invokes its
    run() function. */
bool
Thread::start()
{
    return pthread_create(&m_Thread, &m_Attr, threadFunc, this) == 0;
}

/** Wait for thread exist. Waits until the thread has terminated. */
void
Thread::join()
{
    pthread_join(m_Thread, 0);
}
