/**
  *  \file thread.h
  *  \brief Thread class declaration for Unix
  */
#ifndef THREAD_H_INCLUDED
#define THREAD_H_INCLUDED

#include <pthread.h>

//@{
///\ingroup unix

/** Thread class. Reference to an asynchrounously running part of the
    program. User implements a thread by deriving from this class and
    implementing its run() method.

    The Unix implementation uses pthreads in a straightforward manner. */
class Thread {
    pthread_t m_Thread;

    pthread_attr_t m_Attr;

    static void* threadFunc(void*);
 protected:
    void exit();

    virtual void run() = 0;
 public:
    Thread();

    virtual ~Thread();

    void setStackSize(int n);

    bool start();

    void join();
};

//@}

#endif
