/**
  *  \file socket.h
  */

#include <iostream>
#include "socket.h"
#include "nls.h"

struct WSAInitializer {
    WSAInitializer() {
        WSADATA wsadata;
        WSAStartup(MAKEWORD(2,0), &wsadata);
    }
} socket_initializer;

int
Socket::checkInit(int n)
{
    // static bool been_here = 0;
    // if (!been_here) {
    //     been_here = true;
    //     std::cout << "initializing sockets..." << std::endl;
    //     WSADATA wsadata;
    //     WSAStartup(MAKEWORD(2,0), &wsadata);
    // }
    return n;
}

std::string
Socket::getError()
{
    int n = WSAGetLastError();
    switch (n) {
     case 0:                 return _("No error");
     case WSAEACCES:         return _("Operation not permitted");
     case WSAEADDRINUSE:     return _("Address already in use");
     case WSAEADDRNOTAVAIL:  return _("Address is not available from here");
     case WSAEAFNOSUPPORT:   return _("Address family not supported");
     case WSAEALREADY:       return _("Nonblocking operation already in progress");
     case WSAECONNABORTED:   return _("Connection aborted");
     case WSAECONNREFUSED:   return _("Connection refused");
     case WSAECONNRESET:     return _("Connection reset by remote side");
     case WSAEFAULT:         return _("Invalid memory address");
     case WSAEHOSTUNREACH:   return _("Host unreachable");
     case WSAEINPROGRESS:    return _("Socket call in progress");
     case WSAEINTR:          return _("Interrupted");
     case WSAEINVAL:         return _("Invalid parameters");
     case WSAEISCONN:        return _("Socket already connected");
     case WSAEMSGSIZE:       return _("Message too large");
     case WSAENETDOWN:       return _("The network subsystem has failed");
     case WSAENETRESET:      return _("Connection lost due to remote reset");
     case WSAENETUNREACH:    return _("Network unreachable");
     case WSAENOBUFS:        return _("No buffer space available");
     case WSAENOTCONN:       return _("Socket not connected");
     case WSAENOTSOCK:       return _("Not a socket");
     case WSAEOPNOTSUPP:     return _("Operation not supported");
     case WSAESHUTDOWN:      return _("Socket has been shut down");
     case WSAETIMEDOUT:      return _("Timeout");
     case WSAEWOULDBLOCK:    return _("Operation would block");
     case WSAHOST_NOT_FOUND: return _("Host not found (authoritative)");
     case WSANOTINITIALISED: return _("Socket subsystem not initialized");
     case WSANO_DATA:        return _("Valid name, no data record of requested type");
     case WSANO_RECOVERY:    return _("Nonrecoverable error occurred");
     case WSATRY_AGAIN:      return _("Host not found or server failure");
     default:
        return "Socket error " + itoa(n);
    }
}
