/**
  *  \file expander.h
  *  \brief Expander class declaration
  *  \author Stefan Reuther
  */
#ifndef EXPANDER_H_INCLUDED
#define EXPANDER_H_INCLUDED

#include <string>
#include <map>
#include <list>
#include "enumerator.h"
#include "propertyobject.h"

/** Variable expander. Provides storage for variables, and a means of
    expanding strings with variable references. Variables are
    generally stored as lists, and can receive list values using the
    naming convention of KVEnumerator. */
class Expander : private KVEnumerator {
    std::map<std::string, StringList> m_Variables;

    void handleItem(std::string, std::string, std::string);
 public:
    Expander();

    ~Expander();

    void addObject(PropertyObject& obj);

    void addVariable(std::string name, std::string value);
    
    std::string expand(std::string s) const;

    void expandToList(StringList& result, std::string s) const;
};

#endif
