/**
  *  \file game.h
  *  \brief Game class declaration
  *  \author Stefan Reuther
  */
#ifndef GAME_H_INCLUDED
#define GAME_H_INCLUDED

#include <string>
#include <vector>
#include "propertyobject.h"
#include "featureset.h"
#include "request.h"
#include "transaction.h"

class Race;
class Expander;

/** Game definition. */
class Game : public PropertyObject, public Transactable {
 public:
    static const char*const status_table[];

    enum Status {
        StatusNew,           /**< This game is entirely new. It needs to be assigned a game directory. */
        StatusNeedSpecs,     /**< We need to download specs. It already has a game directory. */
        StatusOK             /**< Game is ok. */
    };

    enum RaceName {
        NameFull,
        NameShort,
        NameAdj
    };

 private:
    std::string m_Name;

    std::string m_LocalDir;

    std::string m_GameUrl;

    StringList m_SpecUrls;

    std::string m_HostDir;

    FeatureSet m_UsedFeatures;

    std::vector<Race*> m_Races;

    Status m_Status;

    char m_RaceNames[11 * (30 + 20 + 12)];
 public:

    Game(std::string name);

    ~Game();

    void enumerate(KVEnumerator& e);

    bool assign(std::string name, std::string value, LoaderState& st);

    PropertyObject* createSubtree(std::string name, std::string value, LoaderState& st);

    std::string getName() const
        { return m_Name; }

    void addRace(Race* r);

    Race* getRaceByNumber(int nr);

    Race* getDefaultRace();

    void enumerateRaces(ValueEnumerator<Race>& r);

    std::string getGameUrl() const
        { return m_GameUrl; }

    const StringList& getSpecificationUrls() const
        { return m_SpecUrls; }

    std::string getLocalDirectory() const
        { return m_LocalDir; }

    void setLocalDirectory(std::string dir)
        { m_LocalDir = dir; }

    Status getStatus() const
        { return m_Status; }

    void setStatus(Status st)
        { m_Status = st; }

    void loadRaceNames();

    std::string getRaceName(int race, RaceName type) const;
};

#endif
