/**
  *  \file multirequest.h
  *  \brief MultiRequest container class
  */
#ifndef MULTIREQUEST_H_INCLUDED
#define MULTIREQUEST_H_INCLUDED

#include <vector>
#include <string>
#include "request.h"
#include "transaction.h"

/** Request containing multiple sub-requests. This can be used to
    group small requests together. */
class MultiRequest : public Request, public RequestConsumer, public Transaction {
 public:
    MultiRequest(std::string name);

    explicit MultiRequest(MultiRequest& other);

    ~MultiRequest();

    void run();

    std::string getName();

    void pushRequest(Request* req);

    int getNumRequests() const
        { return m_Requests.size(); }

    Request* getRequestByNumber(int n) const
        { return m_Requests[n]; }

    Request* getFailedRequest() const
        { return m_FailedRequest; }

 private:
    std::string m_Name;

    std::vector<Request*> m_Requests;

    Request* m_FailedRequest;
};

#endif
