/**
  *  \file mailtemplate.h
  *  \brief Parsing of Mail Address Specifications
  *  \author Stefan Reuther
  */
#ifndef MAILTEMPLATE_H_INCLUDED
#define MAILTEMPLATE_H_INCLUDED

#include <string>

/** Parsing extended mailto URLs into mail templates. Standard syntax
    is "mailto:user@host", we allow to append a query string like for
    HTTP URLs: "mailto:user@host?subject=fuu". Especially the subject
    part seems pretty common.

    Currently supported parameters:
    - subject: subject line for mail
    - body: mail body (one line). */
class MailTemplate {
    std::string m_Address;
    std::string m_Subject;
    std::string m_Body;
 public:
    MailTemplate();

    ~MailTemplate();

    bool parse(std::string text);

    /** Get receiver address. */
    std::string getAddress() const
        { return m_Address; }

    /** Get suggested Subject line. */
    std::string getSubject() const
        { return m_Subject; }

    /** Get suggested mail body. */
    std::string getBody() const
        { return m_Body; }

    std::string toString() const;

    /** Check whether this mail template is valid. */
    bool isValid() const
        { return m_Address.size(); }

    /** Reset. Brings object into virgin state. */
    void reset()
        { m_Address.clear(); }
};

#endif
