/**
  *  \file program.h
  *  \brief Program class declaration
  *  \author Stefan Reuther
  */
#ifndef PROGRAM_H_INCLUDED
#define PROGRAM_H_INCLUDED

#include <string>
#include <vector>
#include "propertyobject.h"
#include "featureset.h"
#include "transaction.h"

class Action;

/** Information about a program. Programs provide various features,
    and a number of actions. */
class Program : public PropertyObject, public Transactable {
    std::string m_Name;

    std::string m_Directory;

    std::string m_Version;

    std::string m_Description;

    FeatureSet m_SupportedFeatures;

    FeatureSet m_ProvidedFeatures;

    int m_Preference;

    std::vector<Action*> m_Actions;

 public:
    Program(std::string name);

    ~Program();

    bool assign(std::string name, std::string value, LoaderState& st);

    void enumerate(KVEnumerator& e);

    PropertyObject* createSubtree(std::string name, std::string value, LoaderState& st);

    std::string getName() const;

    std::string getDirectory() const;

    void setDirectory(std::string s);

    bool hasFeature(std::string feature);

    int getPreference() const;

    void setPreference(int n)
        { m_Preference = n; }

    void addAction(Action* a);

    Action* getActionByName(std::string s);

    Action* getCreateActionByName(std::string s);

    void enumerateActions(ValueEnumerator<Action>& e);
};

#endif
