/**
  *  \file propertyobject.h
  *  \brief PropertyObject declaration
  */
#ifndef PROPERTYOBJECT_H_INCLUDED
#define PROPERTYOBJECT_H_INCLUDED

#include "enumerator.h"

class LoaderState;

/** Object with properties. This manages an object which has named
    string properties, and possibly subtrees. It provides virtual
    methods to access these. */
class PropertyObject {
 public:
    PropertyObject();

    virtual ~PropertyObject();

    /** Enumerate all properties of this object. */
    virtual void enumerate(KVEnumerator& e) = 0;

    /** Assign to a property.
        \param name  [in] Name of property to assign to
        \param value [in] Value to assign
        \param st    [in/out] Loader state to configure/track various assignments
        \return true on success, false if property name not known. */
    virtual bool assign(std::string name, std::string value, LoaderState& st) = 0;

    /** Create a subtree. Returns 0 by default.
        \param name  [in] Kind of subtree to create
        \param value [in] Name of this subtree instance
        \param st    [in/out] Loader state to configure/track various assignments
        \return the subtree; 0 if we cannot create it */
    virtual PropertyObject* createSubtree(std::string name, std::string value, LoaderState& st);
};

#endif
