/**
  *  \file request.h
  */
#ifndef REQUEST_H_INCLUDED
#define REQUEST_H_INCLUDED

#include <string>

class CompletionHandler;

/** Generic request. These requests can be processed by a
    WorkerThread. */
class Request {
 public:
    enum Status {
        StatusWaiting,
        StatusRunning,
        StatusFailed,
        StatusSucceeded
    };

    /** Constructor. */
    Request()
        : m_Status(StatusWaiting),
          m_CompletionHandler(0)
        { }

    /** Destructor. */
    virtual ~Request()
        { }

    /** Main entry. */
    virtual void run() = 0;

    /** Get name of this request. For identification by the user. */
    virtual std::string getName() = 0;

    /** Set status of this request. */
    void setStatus(Status st)
        { m_Status = st; }

    /** Get status of this request. */
    Status getStatus() const
        { return m_Status; }

    /** Set completion handler. Only one completion handler can be set
        for each Request. The use of the CompletionHandler is
        completely up to the application, Request does not itself call
        it. */
    void setCompletionHandler(CompletionHandler* p)
        { m_CompletionHandler = p; }

    /** Get completion handler. */
    CompletionHandler* getCompletionHandler() const
        { return m_CompletionHandler; }
 private:
    Status m_Status;

    CompletionHandler* m_CompletionHandler;    
};

/** Request consumer. Accepts submissions of requests and takes over
    ownership. */
class RequestConsumer {
 public:
    virtual ~RequestConsumer()
        { }

    virtual void pushRequest(Request* r) = 0;
};

#endif
