/**
  *  \file scopedlock.h
  */
#ifndef SCOPEDLOCK_H_INCLUDED
#define SCOPEDLOCK_H_INCLUDED

#include "sem.h"

/** Scope-based lock. This pulls a semaphore upon creation, and
    releases it on destruction, thus ensuring correct locking for the
    block it lives in. */
class ScopedLock {
    Semaphore& m_Sem;

 public:
    ScopedLock(Semaphore& sem)
        : m_Sem(sem)
        { m_Sem.wait(); }

    ~ScopedLock()
        { m_Sem.release(); }
};

#endif
