/**
  *  \file turnuploadrequest.h
  */
#ifndef TURNUPLOADREQUEST_H_INCLUDED
#define TURNUPLOADREQUEST_H_INCLUDED

#include "request.h"
#include "turnuploadparser.h"

class Url;
class MailTemplate;
class Game;
class Race;

/** Turn upload. This uploads or mails turn files for one Race. The
    request succeeds when the turn file is successfully transferred;
    if the file has errors, that doesn't cause this request to fail. */
class TurnUploadRequest : public Request {
    Game& m_Game;
    Race& m_Race;

    std::string m_ResultMessage;

    TurnUploadParser m_Parser;

    void doCopy(std::string dir);
    void doUpload(Url&);
    void doMail(MailTemplate&);

 public:
    TurnUploadRequest(Game& game, Race& race);

    ~TurnUploadRequest();

    void run();

    void setResultMessage(std::string msg)
        { m_ResultMessage = msg; }
    
    std::string getResultMessage() const
        { return m_ResultMessage; }

    const TurnUploadParser& getParser() const
        { return m_Parser; }

    std::string getName();
};

#endif
