/**
  *  \file workerthread.h
  */
#ifndef WORKERTHREAD_H_INCLUDED
#define WORKERTHREAD_H_INCLUDED

#include <list>
#include "thread.h"
#include "sem.h"
#include "request.h"

/** Asynchronous worker thread. This can be fed with Request objects
    and processes them asynchronously, one after the other. */
class WorkerThread : public Thread, public RequestConsumer {
    /** Semaphore to control access to the request queues. */
    Semaphore m_QueueMutex;

    /** Semaphore that counts the number of pending requests. */
    Semaphore m_PendingRequestSem;

    /** Semaphore that counts the number of ready requests. */
    Semaphore m_FinishedRequestsSem;

    std::list<Request*> m_PendingRequests;

    std::list<Request*> m_FinishedRequests;

 protected:
    void run();

 public:
    WorkerThread();

    ~WorkerThread();

    void pushRequest(Request* r);

    Request* popFinishedRequest();

    Semaphore& getFinishSemaphore()
        { return m_FinishedRequestsSem; }
};

#endif
