/**
  *  \file statuspanel.h
  */
#ifndef STATUSPANEL_H_INCLUDED
#define STATUSPANEL_H_INCLUDED

#include "api.h"
#include "request.h"

//@{
///\ingroup wingui

/** Widget that displays a network operation status. */
class StatusPanel : public Window {
    /** Title. */
    std::string m_Title;
    /** Status. */
    std::string m_Status;
    /** Color for status. */
    COLORREF m_StatusColor;
    /** Window handle if this window is created. */
    HWND m_Hwnd;
    /** Age in milliseconds. */
    int m_Age;

    static HFONT m_BoldFont, m_NormalFont;
    static int m_DefaultWidth, m_DefaultHeight;

    void draw(HWND hwnd, HDC dc);
 public:
    StatusPanel(std::string title, std::string status, COLORREF statuscolor);

    ~StatusPanel();

    LRESULT handle(HWND hwnd, UINT msg, WPARAM wparam, LPARAM lparam);

    HWND create(int x,                       // horizontal position of window
                int y,                       // vertical position of window
                int nWidth,                  // window width
                int nHeight,                 // window height
                HWND hWndParent);            // handle to parent or owner window

    /** Get window handle. Use to apply Win32 functions to it. */
    HWND getWindowHandle() const
        { return m_Hwnd; }

    /** Increase age by \c n milliseconds. */
    void addAge(int n)
        { m_Age += n; }

    /** Check whether this widget is old enough to be removed from screen. */
    bool isOld() const
        { return m_Age >= 15000; }

    /** Get time until widget is old enough to be removed from screen.
        \pre !isOld() */
    int getTimeUntilOld() const
        { return 15000 - m_Age; }

    /** Get default width for this widget. */
    static int getDefaultWidth()
        { return m_DefaultWidth; }

    /** Get default height for this widget. */
    static int getDefaultHeight()
        { return m_DefaultHeight; }

    static void init();
};

//@}

#endif
